Skip to contents

This function cleans up your dataset after it has been added to the Global Environment. It will remove any blank rows and determine the minimum and maximum values of the dataset.

Usage

cleandata(x = cutoffvalue:::exampledata)

Arguments

x

Your dataset specified as "DatasetName$ColumnName" or converted to a numeric list with a name (e.g., "yourrawdata <- as.numeric(yourrawdata$columnname)"). Regardless of how you import or specify it, data should be a single column of log-transformed data.

Value

Returns your cleaned dataset along with the minimum and maximum values from that dataset.

Examples

mydata <- cleandata(cutoffvalue:::exampledata)